pub struct RapierContextColliders {
pub colliders: ColliderSet,
/* private fields */
}Expand description
The set of colliders part of the simulation.
This should be attached on an entity with a RapierContextSimulation
Fields
colliders: ColliderSetThe set of colliders part of the simulation.
Implementations
Sourceimpl RapierContextColliders
impl RapierContextColliders
Sourcepub fn collider_parent(
&self,
rigidbody_set: &RapierRigidBodySet,
entity: Entity,
) -> Option<Entity>
pub fn collider_parent( &self, rigidbody_set: &RapierRigidBodySet, entity: Entity, ) -> Option<Entity>
If the collider attached to entity is attached to a rigid-body, this
returns the Entity containing that rigid-body.
Sourcepub fn rigid_body_colliders<'a, 'b: 'a>(
&'a self,
entity: Entity,
rigidbody_set: &'b RapierRigidBodySet,
) -> impl Iterator<Item = Entity> + 'a
pub fn rigid_body_colliders<'a, 'b: 'a>( &'a self, entity: Entity, rigidbody_set: &'b RapierRigidBodySet, ) -> impl Iterator<Item = Entity> + 'a
If entity is a rigid-body, this returns the collider Entitys attached
to that rigid-body.
Sourcepub fn collider_entity(&self, handle: ColliderHandle) -> Option<Entity>
pub fn collider_entity(&self, handle: ColliderHandle) -> Option<Entity>
Retrieve the Bevy entity the given Rapier collider (identified by its handle) is attached to.
Sourcepub fn entity_from_collider(collider: &Collider) -> Entity
pub fn entity_from_collider(collider: &Collider) -> Entity
Retrieve the Bevy entity the given Rapier collider is attached to.
Sourcepub fn entity2collider(&self) -> &HashMap<Entity, ColliderHandle>
pub fn entity2collider(&self) -> &HashMap<Entity, ColliderHandle>
The map from entities to collider handles.